;=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
; calc_look.pro - calculate all look direction quantiteis
;=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

; last modified: 28-Aug-2002

pro calc_look, mx, my, minL, tp_maglon, mlt_look, spot_average, px, py, pz, from

@euv_imtool-commons

; set some things, depending on which window the event came from
if (from eq 0) then begin
    delta_x = center_x2 - (xdim2/2)
    delta_y = center_y2 - (ydim2/2)
    xdimension = xdim2
    ydimension = ydim2
endif else begin
    delta_x = center_x3 - (xdim3/2)
    delta_y = center_y3 - (ydim3/2)
    xdimension = xdim3
    ydimension = ydim3
endelse

; ----------------------------
; determine the look direction
; ----------------------------
get_lookv,mx-delta_x,my-delta_y,xdimension,ydimension,$
  [image_smx/EARTH_RADIUS,image_smy/EARTH_RADIUS,image_smz/EARTH_RADIUS],$
  [-image_smvx,-image_smvy, -image_smvz],lookv

; -----------------------------------------------
; calculate the minimum L along the line of sight
; -----------------------------------------------
result = get_min_l([double(image_smx/EARTH_RADIUS), double(image_smy/EARTH_RADIUS), $
                    double(image_smz/EARTH_RADIUS)], $
                   [double(lookv[0]), double(lookv[1]), double(lookv[2])], 0)

minL = result[0]
px = result[1]
py = result[2]
pz = result[3]

; --------------------------------------------------------
; calculate the magnetic longitude and magnetic local time
; --------------------------------------------------------
along = atan(py, px)
mlt_look = ((along + !PI) * !RADEG) / 15.0
if(mlt_look gt 24.0) then mlt_look = mlt_look - 24.0

tp_sm = [px,py,pz]
tp_mag = t5##t1##transpose(t2)##transpose(t3)##transpose(t4)##tp_sm
tp_maglon = atan(tp_mag[1],tp_mag[0]) * !RADEG
if (tp_maglon lt 0.0) then tp_maglon = tp_maglon + 360.0

; ------------------------
; calculate a spot average
; ------------------------
if(from eq 1) then begin
    mousex = fix((float(mx) / 3.0) * 2.0)
    mousey = fix((float(my) / 3.0) * 2.0)
endif else begin
    mousex = mx
    mousey = my
endelse

sminx = (mousex - 1) > 0
smaxx = (mousex + 1) < (xdim*2 - 1)
sminy = (mousey - 1) > 0
smaxy = (mousey + 1) < (ydim*2 - 1)
npix  = (smaxx-sminx+1) * (smaxy-sminy+1)
spot_average = total(darrayl[sminx:smaxx,sminy:smaxy]) / float(npix)


end
